@@ -22,6 +22,7 @@ calibration observations always are an available target).
 use 5.006;
 use strict;
 use warnings;
+use Carp;
 
 our $VERSION = '0.03';
 
@@ -53,7 +54,7 @@ sub new {
   my $class = ref($proto) || $proto;
   my %args = @_;
 
-  my $self = $class->SUPER::new( az => 0.0, el => 90.0 );
+  my $self = $class->SUPER::new( az => 0.0, el => 90.0, units => 'deg' );
   $self->name( $args{name} ) if exists $args{name};
 
   return $self;
@@ -152,6 +153,17 @@ sub summary {
   return sprintf("%-16s  %-12s  %-13s    CAL",$name,'','');
 }
 
+=item B<apply_offset>
+
+Overrided method to prevent C<Astro::Coords::apply_offset> being
+called on this subclass.
+
+=cut
+
+sub apply_offset {
+  croak 'apply_offset: attempting to apply an offset to a calibration';
+}
+
 =back
 
 =head1 NOTES
@@ -160,7 +172,7 @@ Usually called via C<Astro::Coords>.
 
 =head1 REQUIREMENTS
 
-C<Astro::SLA> is used for all internal astrometric calculations.
+C<Astro::PAL> is used for all internal astrometric calculations.
 
 =head1 AUTHOR
 
